SCPI abstraction for SCPI commands and parameters
=================================================
This is a very rudimentary implementation of a SCPI abstraction/command+parameter interface for SCPI devices

Several features are not implemented (yet) and parsing is often not fully waterproof.
